struct Buffer {
bytes: Box<[u8]>,
read_mark: usize,
write_mark: usize,
}Fields
bytes: Box<[u8]>read_mark: usizewrite_mark: usizeImplementations
Sourceimpl Buffer
impl Buffer
fn new() -> Self
Sourcefn fill_cscsc(&mut self) -> u8
fn fill_cscsc(&mut self) -> u8
When encoding a sequence cScSc where c is any character and S is any string
this results in two codes AB, A encoding cS and B encoding cSc. Supposing
the buffer is already filled with the reconstruction of A, we can easily fill it
with the reconstruction of B.
fn fill_reconstruct(&mut self, table: &Table, code: u16) -> u8
fn buffer(&self) -> &[u8] ⓘ
fn consume(&mut self, amt: usize)